@@ -129,7 +129,7 @@ typedef enum CpaCyKptKeyManagementStatus_t
     /**< SWK count exceeds the configured maximum value per PASID */
     CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED,
     /**< SWK count exceeds the configured maximum value when not scoped to
-    * VFID or PASID*/
+     * VFID or PASID */
     CPA_CY_KPT_SWK_FAIL_NOT_FOUND,
     /**< Unable to find SWK entry by handle */
     CPA_CY_KPT_FAILED,
@@ -157,9 +157,9 @@ typedef enum CpaCyKptKeyManagementStatus_t
 typedef struct CpaCyKptValidationKey_t
 {
     CpaCyRsaPublicKey publicKey;
-        /**< Key */
+    /**< Key */
     Cpa8U signature[CPA_CY_RSA3K_SIG_SIZE_INBYTES];
-        /**< Signature of key */
+    /**< Signature of key */
 } CpaCyKptValidationKey;
 
 /**
@@ -206,7 +206,7 @@ typedef struct CpaCyKptLoadKey_t
  *@see  cpaCyKptUnwrapContext
  *
  *****************************************************************************/
-#define CPA_CY_KPT_MAX_IV_LENGTH  (12)
+#define CPA_CY_KPT_MAX_IV_LENGTH (12)
 
 /**
  *****************************************************************************
@@ -219,7 +219,7 @@ typedef struct CpaCyKptLoadKey_t
  *@see  cpaCyKptUnwrapContext
  *
  *****************************************************************************/
-#define CPA_CY_KPT_MAX_AAD_LENGTH  (16)
+#define CPA_CY_KPT_MAX_AAD_LENGTH (16)
 
 /**
  *****************************************************************************
@@ -238,7 +238,7 @@ typedef struct CpaCyKptUnwrapContext_t
     /**< This is application's unique handle that identifies its
      * (symmetric) wrapping key*/
     Cpa8U iv[CPA_CY_KPT_MAX_IV_LENGTH];
-    /**< Initialization Vector */
+    /**< Initialization Vector - which must be a nonce */
     Cpa8U additionalAuthData[CPA_CY_KPT_MAX_AAD_LENGTH];
     /**< A buffer holding the Additional Authenticated Data.*/
     Cpa32U aadLenInBytes;
@@ -260,8 +260,9 @@ typedef struct CpaCyKptUnwrapContext_t
  *      "||" - denotes concatenation
  *      Key = SWK
  *      AAD = DER(OID)
+ *      IV = nonce
  *      Input = (D || N)
- *      Encrypt (SWK, AAD, (D || N))
+ *      Encrypt (SWK, AAD, IV, (D || N))
  *      Output (AuthTag, (D || N)')
  *      EncryptedRSAKey = (D || N)'
  *
@@ -285,6 +286,7 @@ typedef struct CpaCyKptUnwrapContext_t
  * @note It is important that the value D is big enough. It is STRONGLY
  *      recommended that this value is at least half the length of the modulus
  *      N to protect against the Wiener attack.
+ *      It is critical a unique nonce is used for each SWK encrypt operation.
  *
  *****************************************************************************/
 typedef struct CpaCyKptRsaPrivateKeyRep1_t
@@ -307,10 +309,11 @@ typedef struct CpaCyKptRsaPrivateKeyRep1_t
  *      Encrypt - AES-256-GCM (Key, AAD, Input)
  *      "||" - denotes concatenation
  *      Key = SWK
+ *      IV = nonce
  *      AAD = DER(OID)
  *      Input = (P || Q || dP || dQ || Qinv || publicExponentE)
  *      Expanded Description:
- *         Encrypt (SWK, AAD,
+ *         Encrypt (SWK, AAD, IV,
  *                     (P || Q || dP || dQ || Qinv || publicExponentE))
  *         EncryptedRSAKey = (P || Q || dP || dQ || Qinv || publicExponentE)'
  *      Output (AuthTag, EncryptedRSAKey)
@@ -339,6 +342,8 @@ typedef struct CpaCyKptRsaPrivateKeyRep1_t
  *      - 4096 bits (512 bytes), or
  *      - 8192 bits (1024 bytes).
  *
+ * @note It is critical a unique nonce is used for each SWK encrypt operation.
+ *
  *****************************************************************************/
 typedef struct CpaCyKptRsaPrivateKeyRep2_t
 {
@@ -420,7 +425,6 @@ typedef struct CpaCyKptRsaDecryptOpData_t
      * endian order. The value MUST be between 0 and the modulus n - 1. */
 } CpaCyKptRsaDecryptOpData;
 
-
 /**
  *****************************************************************************
  * @file cpa_cy_kpt.h
@@ -440,8 +444,9 @@ typedef struct CpaCyKptRsaDecryptOpData_t
  *
  *      Key = SWK
  *      AAD = DER(OID)
+ *      IV = nonce
  *      Input = (d)
- *      Encrypt (SWK, AAD, (d))
+ *      Encrypt (SWK, AAD, IV, (d))
  *      Output (AuthTag, EncryptedECKey)
  *
  *      privatekey == EncryptedECKey || AuthTag
@@ -486,161 +491,165 @@ typedef struct CpaCyKptEcdsaSignRSOpData_t
  *
  *****************************************************************************/
 
- /**
-  *****************************************************************************
-  * @file cpa_cy_kpt.h
-  * @ingroup cpaCyKpt
-  *      Query KPT's issuing public key(R_Pu) and signature from QAT driver.
-  * @description
-  *      This function is to query the RSA3K issuing key and its
-  *      PKCS#1 v2.2 SHA-384 signature from the QAT driver.
-  * @context
-  *      This function may sleep, and  MUST NOT be called in interrupt context.
-  * @assumptions
-  *      None
-  * @sideEffects
-  *      None
-  * @blocking
-  *      This function is synchronous and blocking.
-  * @param[in]  instanceHandle       Instance handle.
-  * @param[out] pIssueCert           KPT-2.0 Issuing certificate in PEM format
-                                     as defined in RFC#7468
-  * @param[out] pKptStatus           One of the status codes denoted in the
-  *                                  enumerate type CpaCyKptKeyManagementStatus
-  *              CPA_CY_KPT_SUCCESS  Issuing key retrieved successfully
-  *              CPA_CY_KPT_FAILED   Operation failed
-  *
-  * @retval CPA_STATUS_SUCCESS       Function executed successfully.
-  * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
-  * @retval CPA_STATUS_FAIL          Function failed. Suggested course of action
-  *                                  is to shutdown and restart.
-  * @retval CPA_STATUS_UNSUPPORTED   Function is not supported.
-  * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
-  *                                  Resubmit the request.
-  *
-  * @pre
-  *      The component has been initialized via cpaCyStartInstance function.
-  * @post
-  *      None
-  * @note
-  *      Note that this is a synchronous function and has no completion callback
-  *      associated with it.
-  * @see
-  *
-  *****************************************************************************/
- CpaStatus
- cpaCyKptQueryIssuingKeys(const CpaInstanceHandle instanceHandle,
-        CpaFlatBuffer *pPublicX509IssueCert,
-        CpaCyKptKeyManagementStatus *pKptStatus);
+/**
+ *****************************************************************************
+ * @file cpa_cy_kpt.h
+ * @ingroup cpaCyKpt
+ *      Query KPT's issuing public key(R_Pu) and signature from QAT driver.
+ * @description
+ *      This function is to query the RSA3K issuing key and its
+ *      PKCS#1 v2.2 SHA-384 signature from the QAT driver.
+ * @context
+ *      This function may sleep, and  MUST NOT be called in interrupt context.
+ * @assumptions
+ *      None
+ * @sideEffects
+ *      None
+ * @blocking
+ *      This function is synchronous and blocking.
+ * @param[in]  instanceHandle       Instance handle.
+ * @param[out] pIssueCert           KPT-2.0 Issuing certificate in PEM format
+                                    as defined in RFC#7468
+ * @param[out] pKptStatus           One of the status codes denoted in the
+ *                                  enumerate type CpaCyKptKeyManagementStatus
+ *                                  CPA_CY_KPT_SUCCESS: Issuing key retrieved
+                                    successfully
+ *                                  CPA_CY_KPT_FAILED: Operation failed
+ *
+ * @retval CPA_STATUS_SUCCESS       Function executed successfully.
+ * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
+ * @retval CPA_STATUS_FAIL          Function failed. Suggested course of action
+ *                                  is to shutdown and restart.
+ * @retval CPA_STATUS_UNSUPPORTED   Function is not supported.
+ * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
+ *                                  Resubmit the request.
+ *
+ * @pre
+ *      The component has been initialized via cpaCyStartInstance function.
+ * @post
+ *      None
+ * @note
+ *      Note that this is a synchronous function and has no completion callback
+ *      associated with it.
+ * @see
+ *
+ *****************************************************************************/
+CpaStatus cpaCyKptQueryIssuingKeys(const CpaInstanceHandle instanceHandle,
+                                   CpaFlatBuffer *pPublicX509IssueCert,
+                                   CpaCyKptKeyManagementStatus *pKptStatus);
 
- /**
-  *****************************************************************************
-  * @file cpa_cy_kpt.h
-  * @ingroup cpaCyKpt
-  *      Query KPT's Per-Part public key(I_pu) and signature from QAT
-  *      device
-  * @description
-  *      This function is to query RSA3K Per-Part public key and its
-  *      PKCS#1 v2.2 SHA-384 signature from the QAT device.
-  * @context
-  *      This function may sleep, and  MUST NOT be called in interrupt context.
-  * @assumptions
-  *      None
-  * @sideEffects
-  *      None
-  * @blocking
-  *      This function is synchronous and blocking.
-  * @param[in]  instanceHandle       Instance handle.
-  * @param[out] pDevCredential       Device Per-Part public key
-  * @param[out] pKptStatus           One of the status codes denoted in the
-  *                                  enumerate type CpaCyKptKeyManagementStatus
-  *              CPA_CY_KPT_SUCCESS  Device credentials retrieved successfully
-  *              CPA_CY_KPT_FAILED   Operation failed
-  *
-  * @retval CPA_STATUS_SUCCESS       Function executed successfully.
-  * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
-  * @retval CPA_STATUS_FAIL          Function failed. Suggested course of action
-  *                                  is to shutdown and restart.
-  * @retval CPA_STATUS_UNSUPPORTED   Function is not supported.
-  * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
-  *                                  Resubmit the request.
-  *
-  * @pre
-  *      The component has been initialized via cpaCyStartInstance function.
-  * @post
-  *      None
-  * @note
-  *      Note that this is a synchronous function and has no completion callback
-  *      associated with it.
-  * @see
-  *
-  *****************************************************************************/
- CpaStatus
- cpaCyKptQueryDeviceCredentials(const CpaInstanceHandle instanceHandle,
-        CpaCyKptValidationKey *pDevCredential,
-        CpaCyKptKeyManagementStatus *pKptStatus);
-
- /**
-  *****************************************************************************
-  * @file cpa_cy_kpt.h
-  * @ingroup cpaCyKpt
-  *      Perform KPT key loading function.
-  *
-  * @description
-  *      This function is invoked by a QAT application to load an encrypted
-  *      symmetric wrapping key.
-  * @context
-  *      This is a synchronous function and it can sleep. It MUST NOT be
-  *      executed in a context that DOES NOT permit sleeping.
-  * @assumptions
-  *      None
-  * @sideEffects
-  *      None
-  * @blocking
-  *      This function is synchronous and blocking.
-  * @reentrant
-  *      No
-  * @threadSafe
-  *      Yes
-  *
-  * @param[in]  instanceHandle      QAT service instance handle.
-  * @param[in]  pSWK                Encrypted SWK
-  * @param[out] keyHandle           A 64-bit handle value created by KPT
-  * @param[out] pKptStatus          One of the status codes denoted in the
-  *                                 enumerate type CpaCyKptKeyManagementStatus
-  *   CPA_CY_KPT_SUCCESS  Key Loaded successfully
-  *   CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED_PER_VFID
-  *       SWK count exceeds the configured maximum value per VFID
-  *   CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED_PER_PASID
-  *       SWK count exceeds the configured maximum value per PASID
-  *   CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED
-  *       SWK count exceeds the configured maximum value when not scoped to
-  *       VFID or PASID
-  *   CPA_CY_KPT_FAILED   Operation failed due to unspecified reason
-  *
-  * @retval CPA_STATUS_SUCCESS       Function executed successfully.
-  * @retval CPA_STATUS_FAIL          Function failed.
-  * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
-  * @retval CPA_STATUS_RESOURCE      Error related to system resources.
-  * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
-  *                                  Resubmit the request.
-  * @retval CPA_STATUS_UNSUPPORTED   KPT-2.0 is not supported.
-  *
-  * @pre
-  *      Component has been initialized.
-  * @post
-  *      None
-  * @note
-  *      None
-  * @see
-  *      None
-  *****************************************************************************/
- CpaStatus
- cpaCyKptLoadKey(CpaInstanceHandle instanceHandle,
-    CpaCyKptLoadKey *pSWK,
-    CpaCyKptHandle *keyHandle,
+/**
+ *****************************************************************************
+ * @file cpa_cy_kpt.h
+ * @ingroup cpaCyKpt
+ *      Query KPT's Per-Part public key(I_pu) and signature from QAT
+ *      device
+ * @description
+ *      This function is to query RSA3K Per-Part public key and its
+ *      PKCS#1 v2.2 SHA-384 signature from the QAT device.
+ * @context
+ *      This function may sleep, and  MUST NOT be called in interrupt context.
+ * @assumptions
+ *      None
+ * @sideEffects
+ *      None
+ * @blocking
+ *      This function is synchronous and blocking.
+ * @param[in]  instanceHandle       Instance handle.
+ * @param[out] pDevCredential       Device Per-Part public key
+ * @param[out] pKptStatus           One of the status codes denoted in the
+ *                                  enumerate type CpaCyKptKeyManagementStatus
+ *                                  CPA_CY_KPT_SUCCESS: Device credentials
+ *                                  retrieved successfully
+ *                                  CPA_CY_KPT_FAILED: Operation failed
+ *
+ * @retval CPA_STATUS_SUCCESS       Function executed successfully.
+ * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
+ * @retval CPA_STATUS_FAIL          Function failed. Suggested course of action
+ *                                  is to shutdown and restart.
+ * @retval CPA_STATUS_UNSUPPORTED   Function is not supported.
+ * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
+ *                                  Resubmit the request.
+ *
+ * @pre
+ *      The component has been initialized via cpaCyStartInstance function.
+ * @post
+ *      None
+ * @note
+ *      Note that this is a synchronous function and has no completion callback
+ *      associated with it.
+ * @see
+ *
+ *****************************************************************************/
+CpaStatus cpaCyKptQueryDeviceCredentials(
+    const CpaInstanceHandle instanceHandle,
+    CpaCyKptValidationKey *pDevCredential,
     CpaCyKptKeyManagementStatus *pKptStatus);
 
+/**
+ *****************************************************************************
+ * @file cpa_cy_kpt.h
+ * @ingroup cpaCyKpt
+ *      Perform KPT key loading function.
+ *
+ * @description
+ *      This function is invoked by a QAT application to load an encrypted
+ *      symmetric wrapping key.
+ * @context
+ *      This is a synchronous function and it can sleep. It MUST NOT be
+ *      executed in a context that DOES NOT permit sleeping.
+ * @assumptions
+ *      None
+ * @sideEffects
+ *      None
+ * @blocking
+ *      This function is synchronous and blocking.
+ * @reentrant
+ *      No
+ * @threadSafe
+ *      Yes
+ *
+ * @param[in]  instanceHandle      QAT service instance handle.
+ * @param[in]  pSWK                Encrypted SWK
+ * @param[out] keyHandle           A 64-bit handle value created by KPT
+ * @param[out] pKptStatus          One of the status codes denoted in the
+ *                                 enumerate type CpaCyKptKeyManagementStatus
+ *                                 CPA_CY_KPT_SUCCESS:
+ *                                 Key Loaded successfully
+ *                                 CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED_PER_VFID:
+ *                                 SWK count exceeds the configured maximum
+ *                                 value per VFID
+ *                                 CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED_PER_PASID:
+ *                                 SWK count exceeds the configured maximum
+ *                                 value per PASID
+ *                                 CPA_CY_KPT_LOADKEY_FAIL_QUOTA_EXCEEDED: SWK
+ *                                 count exceeds the configured maximum value
+ *                                 when not scoped to VFID or
+ *                                 PASID CPA_CY_KPT_FAILED: Operation failed due
+ *                                 to unspecified reason
+ *
+ * @retval CPA_STATUS_SUCCESS       Function executed successfully.
+ * @retval CPA_STATUS_FAIL          Function failed.
+ * @retval CPA_STATUS_INVALID_PARAM Invalid parameter passed in.
+ * @retval CPA_STATUS_RESOURCE      Error related to system resources.
+ * @retval CPA_STATUS_RESTARTING    API implementation is restarting.
+ *                                  Resubmit the request.
+ * @retval CPA_STATUS_UNSUPPORTED   KPT-2.0 is not supported.
+ *
+ * @pre
+ *      Component has been initialized.
+ * @post
+ *      None
+ * @note
+ *      None
+ * @see
+ *      None
+ *****************************************************************************/
+CpaStatus cpaCyKptLoadKey(CpaInstanceHandle instanceHandle,
+                          CpaCyKptLoadKey *pSWK,
+                          CpaCyKptHandle *keyHandle,
+                          CpaCyKptKeyManagementStatus *pKptStatus);
+
 /**
  *****************************************************************************
  * @file cpa_cy_kpt.h
@@ -670,10 +679,11 @@ typedef struct CpaCyKptEcdsaSignRSOpData_t
  * @param[in]  keyHandle            A 64-bit handle value
  * @param[out] pkptstatus           One of the status codes denoted in the
  *                                  enumerate type CpaCyKptKeyManagementStatus
- *   CPA_CY_KPT_SUCCESS  Key Deleted successfully
- *   CPA_CY_KPT_SWK_FAIL_NOT_FOUND For any reason the input handle cannot be
- *        found.
- *   CPA_CY_KPT_FAILED   Operation failed due to unspecified reason
+ *                                  CPA_CY_KPT_SUCCESS: Key Deleted successfully
+ *                                  CPA_CY_KPT_SWK_FAIL_NOT_FOUND: For any
+ *                                  reason the input handle cannot be found.
+ *                                  CPA_CY_KPT_FAILED: Operation failed due to
+ *                                  unspecified reason
  *
  * @retval CPA_STATUS_SUCCESS        Function executed successfully.
  * @retval CPA_STATUS_FAIL           Function failed.
@@ -690,10 +700,9 @@ typedef struct CpaCyKptEcdsaSignRSOpData_t
  * @see
  *      None
  *****************************************************************************/
-CpaStatus
-cpaCyKptDeleteKey(CpaInstanceHandle instanceHandle,
-        CpaCyKptHandle keyHandle,
-        CpaCyKptKeyManagementStatus *pKptStatus);
+CpaStatus cpaCyKptDeleteKey(CpaInstanceHandle instanceHandle,
+                            CpaCyKptHandle keyHandle,
+                            CpaCyKptKeyManagementStatus *pKptStatus);
 
 /**
 *****************************************************************************
@@ -786,13 +795,12 @@ cpaCyKptDeleteKey(CpaInstanceHandle instanceHandle,
  *      CpaCyGenFlatBufCbFunc,
  *
  *****************************************************************************/
-CpaStatus
-cpaCyKptRsaDecrypt(const CpaInstanceHandle instanceHandle,
-        const CpaCyGenFlatBufCbFunc pRsaDecryptCb,
-        void *pCallbackTag,
-        const CpaCyKptRsaDecryptOpData *pDecryptOpData,
-        CpaFlatBuffer *pOutputData,
-        CpaCyKptUnwrapContext *pKptUnwrapContext);
+CpaStatus cpaCyKptRsaDecrypt(const CpaInstanceHandle instanceHandle,
+                             const CpaCyGenFlatBufCbFunc pRsaDecryptCb,
+                             void *pCallbackTag,
+                             const CpaCyKptRsaDecryptOpData *pDecryptOpData,
+                             CpaFlatBuffer *pOutputData,
+                             CpaCyKptUnwrapContext *pKptUnwrapContext);
 
 /**
  *****************************************************************************
@@ -852,26 +860,24 @@ cpaCyKptRsaDecrypt(const CpaInstanceHandle instanceHandle,
  *      None
  * @note
  *      By virtue of invoking the cpaCyKptEcdsaSignRS, the implementation
- *      understands CpaCyEcdsaSignRSOpData contains an encrypted private key that
- *      requires unwrapping. KptUnwrapContext contains a 'KptHandle' field
- *      that points to the unwrapping key in the WKT.
- *      When pCb is non-NULL an asynchronous callback of type
- *      CpaCyEcdsaSignRSCbFunc generated in response to this function
- *      call.
+ *      understands CpaCyEcdsaSignRSOpData contains an encrypted private key
+ *      that requires unwrapping. KptUnwrapContext contains a 'KptHandle' field
+ *      that points to the unwrapping key in the WKT. When pCb is non-NULL an
+ *      asynchronous callback of type CpaCyEcdsaSignRSCbFunc generated in
+ *      response to this function call.
  *      In KPT release, private key field in CpaCyEcdsaSignRSOpData is a
  *      concatenation of cipher text and hash tag.
  * @see
  *      None
  *****************************************************************************/
-CpaStatus
-cpaCyKptEcdsaSignRS(const CpaInstanceHandle instanceHandle,
-        const CpaCyEcdsaSignRSCbFunc pCb,
-        void *pCallbackTag,
-        const CpaCyKptEcdsaSignRSOpData *pOpData,
-        CpaBoolean *pSignStatus,
-        CpaFlatBuffer *pR,
-        CpaFlatBuffer *pS,
-        CpaCyKptUnwrapContext *pKptUnwrapContext);
+CpaStatus cpaCyKptEcdsaSignRS(const CpaInstanceHandle instanceHandle,
+                              const CpaCyEcdsaSignRSCbFunc pCb,
+                              void *pCallbackTag,
+                              const CpaCyKptEcdsaSignRSOpData *pOpData,
+                              CpaBoolean *pSignStatus,
+                              CpaFlatBuffer *pR,
+                              CpaFlatBuffer *pS,
+                              CpaCyKptUnwrapContext *pKptUnwrapContext);
 
 #ifdef __cplusplus
 } /* close the extern "C" { */
