@@ -84,6 +84,7 @@
 #include "lac_mem.h"
 #include "cpa_cy_common.h"
 #include "dc_session.h"
+#include "dc_datapath.h"
 #include "sal_misc_error_stats.h"
 
 /*
@@ -94,18 +95,22 @@
 /* Invalid physical address value */
 #define INVALID_PHYSICAL_ADDRESS 0
 
+#define MAX_SGL_BUFFERS 256
+
 /* Indicates what type of buffer writes need to be performed */
 typedef enum lac_buff_write_op_e
 {
     WRITE_NORMAL = 0,
     WRITE_AND_GET_SIZE,
     WRITE_AND_ALLOW_ZERO_BUFFER,
+    WRITE_ALLOW_0_BUFF_GET_SIZE,
 } lac_buff_write_op_t;
 
 /* This function implements the buffer description writes for the traditional
  * APIs */
 STATIC CpaStatus
 LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
+                                      const CpaBufferList *pDictBufferList,
                                       Cpa64U *pBufListAlignedPhyAddr,
                                       CpaBoolean isPhysicalAddress,
                                       Cpa64U *totalDataLenInBytes,
@@ -113,26 +118,26 @@ LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
                                       lac_buff_write_op_t operationType)
 {
     Cpa32U numBuffers = 0;
+    Cpa32U dictNumBuffers = 0;
     icp_qat_addr_width_t bufListDescPhyAddr = 0;
     icp_qat_addr_width_t bufListAlignedPhyAddr = 0;
     CpaFlatBuffer *pCurrClientFlatBuffer = NULL;
     icp_buffer_list_desc_t *pBufferListDesc = NULL;
     icp_flat_buffer_desc_t *pCurrFlatBufDesc = NULL;
+    Cpa64U internalDataLenInBytes = 0;
 
     LAC_ENSURE_NOT_NULL(pUserBufferList);
     LAC_ENSURE_NOT_NULL(pUserBufferList->pBuffers);
     LAC_ENSURE_NOT_NULL(pUserBufferList->pPrivateMetaData);
     LAC_ENSURE_NOT_NULL(pBufListAlignedPhyAddr);
 
-    if (WRITE_AND_GET_SIZE == operationType)
+    if (WRITE_AND_GET_SIZE == operationType ||
+        WRITE_ALLOW_0_BUFF_GET_SIZE == operationType)
     {
         LAC_ENSURE_NOT_NULL(totalDataLenInBytes);
         *totalDataLenInBytes = 0;
     }
 
-    numBuffers = pUserBufferList->numBuffers;
-    pCurrClientFlatBuffer = pUserBufferList->pBuffers;
-
     /*
      * Get the physical address of this descriptor - need to offset by the
      * alignment restrictions on the buffer descriptors
@@ -158,17 +163,86 @@ LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
     pCurrFlatBufDesc =
         (icp_flat_buffer_desc_t *)((pBufferListDesc->phyBuffers));
 
-    pBufferListDesc->numBuffers = numBuffers;
-
-    if (WRITE_AND_GET_SIZE != operationType)
+    if (pDictBufferList != NULL)
     {
-        /* Defining zero buffers is useful for example if running zero length
-         * hash */
+        numBuffers = pDictBufferList->numBuffers;
+        pCurrClientFlatBuffer = pDictBufferList->pBuffers;
+
+        if (numBuffers >= MAX_SGL_BUFFERS)
+        {
+            LAC_LOG_ERROR("Max SGL buffers exceeded\n");
+            return CPA_STATUS_FAIL;
+        }
+
         if (0 == numBuffers)
         {
-            /* In the case where there are zero buffers within the BufList
-             * it is required by firmware that the number is set to 1
-             * but the phyBuffer and dataLenInBytes are set to NULL.*/
+            LAC_LOG_ERROR("Zero buffer requests are not allowed for "
+                          "dictionary APIs\n");
+            return CPA_STATUS_FAIL;
+        }
+
+        while (0 != numBuffers)
+        {
+            pCurrFlatBufDesc->dataLenInBytes =
+                pCurrClientFlatBuffer->dataLenInBytes;
+
+            /* Calculate the total data length in bytes */
+            internalDataLenInBytes += pCurrClientFlatBuffer->dataLenInBytes;
+
+            /* Check if a physical address is provided in the function. If not
+             * we need to convert it to a physical one */
+            if (CPA_TRUE == isPhysicalAddress)
+            {
+                pCurrFlatBufDesc->phyBuffer = LAC_MEM_CAST_PTR_TO_UINT64(
+                    (LAC_ARCH_UINT)(pCurrClientFlatBuffer->pData));
+            }
+            else
+            {
+                pCurrFlatBufDesc->phyBuffer =
+                    LAC_MEM_CAST_PTR_TO_UINT64(LAC_OS_VIRT_TO_PHYS_EXTERNAL(
+                        (*pService), pCurrClientFlatBuffer->pData));
+
+                if (INVALID_PHYSICAL_ADDRESS == pCurrFlatBufDesc->phyBuffer)
+                {
+                    LAC_LOG_ERROR("Unable to get the physical address of the "
+                                  "client buffer\n");
+                    return CPA_STATUS_FAIL;
+                }
+            }
+
+            pCurrFlatBufDesc++;
+            pCurrClientFlatBuffer++;
+            numBuffers--;
+        }
+        dictNumBuffers += pDictBufferList->numBuffers;
+    }
+
+    pBufferListDesc->numBuffers = pUserBufferList->numBuffers + dictNumBuffers;
+    numBuffers = pUserBufferList->numBuffers;
+    pCurrClientFlatBuffer = pUserBufferList->pBuffers;
+
+    if (pBufferListDesc->numBuffers >= MAX_SGL_BUFFERS)
+    {
+        LAC_LOG_ERROR("Max SGL buffers exceeded\n");
+        return CPA_STATUS_FAIL;
+    }
+
+    if (0 == numBuffers)
+    {
+        if (pDictBufferList != NULL ||
+            (WRITE_AND_ALLOW_ZERO_BUFFER != operationType &&
+             WRITE_ALLOW_0_BUFF_GET_SIZE != operationType))
+        {
+            LAC_LOG_ERROR("Zero length buffer requests are not allowed for "
+                          "this operation\n");
+            return CPA_STATUS_FAIL;
+        }
+        else
+        {
+            /* Defining zero length buffers is useful for example if running
+             * zero length hash. In the case where there are zero buffers within
+             * the BufList it is required by firmware that the number is set to
+             * 1 but the phyBuffer and dataLenInBytes are set to NULL. */
             pBufferListDesc->numBuffers = 1;
             pCurrFlatBufDesc->dataLenInBytes = 0;
             pCurrFlatBufDesc->phyBuffer = 0;
@@ -180,11 +254,8 @@ LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
         pCurrFlatBufDesc->dataLenInBytes =
             pCurrClientFlatBuffer->dataLenInBytes;
 
-        if (WRITE_AND_GET_SIZE == operationType)
-        {
-            /* Calculate the total data length in bytes */
-            *totalDataLenInBytes += pCurrClientFlatBuffer->dataLenInBytes;
-        }
+        /* Calculate the total data length in bytes */
+        internalDataLenInBytes += pCurrClientFlatBuffer->dataLenInBytes;
 
         /* Check if providing a physical address in the function. If not we
          * need to convert it to a physical one */
@@ -199,7 +270,8 @@ LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
                 LAC_MEM_CAST_PTR_TO_UINT64(LAC_OS_VIRT_TO_PHYS_EXTERNAL(
                     (*pService), pCurrClientFlatBuffer->pData));
 
-            if (WRITE_AND_ALLOW_ZERO_BUFFER != operationType)
+            if (WRITE_AND_ALLOW_ZERO_BUFFER != operationType &&
+                WRITE_ALLOW_0_BUFF_GET_SIZE != operationType)
             {
                 if (INVALID_PHYSICAL_ADDRESS == pCurrFlatBufDesc->phyBuffer)
                 {
@@ -212,11 +284,22 @@ LacBuffDesc_CommonBufferListDescWrite(const CpaBufferList *pUserBufferList,
 
         pCurrFlatBufDesc++;
         pCurrClientFlatBuffer++;
-
         numBuffers--;
     }
 
+    if (pDictBufferList != NULL && internalDataLenInBytes > DC_BUFFER_MAX_SIZE)
+    {
+        LAC_LOG_ERROR("Total data length including dictionary has exceeded "
+                      "max limits\n");
+        return CPA_STATUS_FAIL;
+    }
+
     *pBufListAlignedPhyAddr = bufListAlignedPhyAddr;
+    if (WRITE_AND_GET_SIZE == operationType ||
+        WRITE_ALLOW_0_BUFF_GET_SIZE == operationType)
+    {
+        *totalDataLenInBytes = internalDataLenInBytes;
+    }
     return CPA_STATUS_SUCCESS;
 }
 
@@ -230,6 +313,7 @@ CpaStatus LacBuffDesc_BufferListDescWriteAndAllowZeroBuffer(
     sal_service_t *pService)
 {
     return LacBuffDesc_CommonBufferListDescWrite(pUserBufferList,
+                                                 NULL,
                                                  pBufListAlignedPhyAddr,
                                                  isPhysicalAddress,
                                                  NULL,
@@ -237,6 +321,26 @@ CpaStatus LacBuffDesc_BufferListDescWriteAndAllowZeroBuffer(
                                                  WRITE_AND_ALLOW_ZERO_BUFFER);
 }
 
+/* This function does the same processing as
+ * LacBuffDesc_BufferListDescWriteAndAllowZeroBuffer but also
+ * calculates the total length in bytes of the buffer list.
+ */
+CpaStatus LacBuffDesc_BufferListDescWriteAllow0BuffGetSize(
+    const CpaBufferList *pUserBufferList,
+    Cpa64U *pBufListAlignedPhyAddr,
+    CpaBoolean isPhysicalAddress,
+    Cpa64U *totalDataLenInBytes,
+    sal_service_t *pService)
+{
+    return LacBuffDesc_CommonBufferListDescWrite(pUserBufferList,
+                                                 NULL,
+                                                 pBufListAlignedPhyAddr,
+                                                 isPhysicalAddress,
+                                                 totalDataLenInBytes,
+                                                 pService,
+                                                 WRITE_ALLOW_0_BUFF_GET_SIZE);
+}
+
 /* This function implements the buffer description writes for the traditional
  * APIs */
 CpaStatus LacBuffDesc_BufferListDescWrite(const CpaBufferList *pUserBufferList,
@@ -245,6 +349,7 @@ CpaStatus LacBuffDesc_BufferListDescWrite(const CpaBufferList *pUserBufferList,
                                           sal_service_t *pService)
 {
     return LacBuffDesc_CommonBufferListDescWrite(pUserBufferList,
+                                                 NULL,
                                                  pBufListAlignedPhyAddr,
                                                  isPhysicalAddress,
                                                  NULL,
@@ -262,6 +367,27 @@ CpaStatus LacBuffDesc_BufferListDescWriteAndGetSize(
     sal_service_t *pService)
 {
     return LacBuffDesc_CommonBufferListDescWrite(pUserBufferList,
+                                                 NULL,
+                                                 pBufListAlignedPhyAddr,
+                                                 isPhysicalAddress,
+                                                 totalDataLenInBytes,
+                                                 pService,
+                                                 WRITE_AND_GET_SIZE);
+}
+
+/* This function does the same processing as
+ * LacBuffDesc_BufferListDescWriteAndGetSize but includes an extra
+ * dictionary buffer at the start of the meta data. */
+CpaStatus LacBuffDesc_BufferListDescWriteWithDictAndGetSize(
+    const CpaBufferList *pUserBufferList,
+    const CpaBufferList *pDictionaryBufferList,
+    Cpa64U *pBufListAlignedPhyAddr,
+    CpaBoolean isPhysicalAddress,
+    Cpa64U *totalDataLenInBytes,
+    sal_service_t *pService)
+{
+    return LacBuffDesc_CommonBufferListDescWrite(pUserBufferList,
+                                                 pDictionaryBufferList,
                                                  pBufListAlignedPhyAddr,
                                                  isPhysicalAddress,
                                                  totalDataLenInBytes,
@@ -275,7 +401,6 @@ CpaStatus LacBuffDesc_FlatBufferVerify(
     lac_aligment_shift_t alignmentShiftExpected)
 {
     LAC_CHECK_NULL_PARAM(pUserFlatBuffer);
-    LAC_ENSURE_NOT_NULL(pPktSize);
     LAC_CHECK_NULL_PARAM(pUserFlatBuffer->pData);
 
     if (0 == pUserFlatBuffer->dataLenInBytes)
@@ -375,6 +500,41 @@ CpaStatus LacBuffDesc_BufferListVerify(
     return status;
 }
 
+CpaStatus LacBuffDesc_BufferListVerifyNoMetadata(
+    const CpaBufferList *pUserBufferList,
+    Cpa64U *pPktSize,
+    lac_aligment_shift_t alignmentShiftExpected)
+{
+    CpaFlatBuffer *pCurrClientFlatBuffer = NULL;
+    Cpa32U numBuffers = 0;
+    CpaStatus status = CPA_STATUS_SUCCESS;
+
+    LAC_CHECK_NULL_PARAM(pUserBufferList);
+    LAC_CHECK_NULL_PARAM(pUserBufferList->pBuffers);
+    LAC_ENSURE_NOT_NULL(pPktSize);
+
+    numBuffers = pUserBufferList->numBuffers;
+
+    if (0 == pUserBufferList->numBuffers)
+    {
+        LAC_INVALID_PARAM_LOG("Number of buffers");
+        return CPA_STATUS_INVALID_PARAM;
+    }
+
+    pCurrClientFlatBuffer = pUserBufferList->pBuffers;
+
+    *pPktSize = 0;
+    while (0 != numBuffers && status == CPA_STATUS_SUCCESS)
+    {
+        status = LacBuffDesc_FlatBufferVerify(
+            pCurrClientFlatBuffer, pPktSize, alignmentShiftExpected);
+
+        pCurrClientFlatBuffer++;
+        numBuffers--;
+    }
+    return status;
+}
+
 CpaStatus LacBuffDesc_BufferListVerifyNull(
     const CpaBufferList *pUserBufferList,
     Cpa64U *pPktSize,
