@@ -182,7 +182,7 @@ static CpaStatus sampleDhPerformOp(CpaInstanceHandle cyInstHandle)
     /* The following variables are allocated on the stack because we block
      * until the callback comes back. If a non-blocking approach was to be
      * used then these variables should be dynamically allocated */
-    struct COMPLETION_STRUCT complete = { 0 };
+    struct COMPLETION_STRUCT complete;
     void *pCallbackTagPh2 = (void *)&complete;
 
     /** Pointer that will contain the public value (returned by
@@ -196,6 +196,8 @@ static CpaStatus sampleDhPerformOp(CpaInstanceHandle cyInstHandle)
 
     CpaCyDhPhase1KeyGenOpData *pCpaDhOpDataP1 = NULL;
 
+    COMPLETION_INIT(&complete); // Initialize the completion variable
+
     //<snippet name="memAlloc">
     status = OS_MALLOC(&pCpaDhOpDataP1, sizeof(CpaCyDhPhase1KeyGenOpData));
 
@@ -339,8 +341,6 @@ static CpaStatus sampleDhPerformOp(CpaInstanceHandle cyInstHandle)
             PRINT_DBG("cpaCyDhKeyGenPhase2Secret\n");
             PRINT_DBG("Phase 2: generate the private key\n");
 
-            COMPLETION_INIT(&complete);
-
             //<snippet name="ph2OpPerform">
             status = cpaCyDhKeyGenPhase2Secret(
                 cyInstHandle,
