@@ -164,6 +164,9 @@ static CpaStatus compPerformOp(CpaInstanceHandle dcInstHandle,
     Cpa8U *pDst2Buffer = NULL;
     CpaDcDpOpData *pOpData = NULL;
     Cpa32U checksum = 0;
+#if defined(SC_BSD_UPSTREAM)
+    CpaInstanceInfo2 info2 = { 0 };
+#endif
 
     //<snippet name="memAlloc">
     numBuffers = 2;
@@ -221,24 +224,34 @@ static CpaStatus compPerformOp(CpaInstanceHandle dcInstHandle,
     }
 #endif
 
+#if defined(SC_BSD_UPSTREAM)
+    status = cpaDcInstanceGetInfo2(dcInstHandle, &info2);
+    if (CPA_STATUS_SUCCESS != status)
+    {
+        PRINT_ERR("cpaDcInstanceGetInfo2 API failed. (status = %d)\n", status);
+        return CPA_STATUS_FAIL;
+    }
+#endif
+
     if (CPA_STATUS_SUCCESS == status)
     {
         /* Allocate destination buffer the same size as source buffer but in
            an SGL with 1 buffer */
-        bufferListMemSize = sizeof(CpaPhysBufferList) + dstBufferSize;
+        bufferListMemSize =
+            sizeof(CpaPhysBufferList) + sizeof(CpaPhysFlatBuffer);
         status =
             PHYS_CONTIG_ALLOC_ALIGNED(&pBufferListDst, bufferListMemSize, 8);
     }
 
     if (CPA_STATUS_SUCCESS == status)
     {
-        status = PHYS_CONTIG_ALLOC(&pDstBuffer, bufferSize);
+        status = PHYS_CONTIG_ALLOC(&pDstBuffer, dstBufferSize);
     }
     if (CPA_STATUS_SUCCESS == status)
     {
         /* Build destination bufferList */
         pBufferListDst->numBuffers = 1;
-        pBufferListDst->flatBuffers[0].dataLenInBytes = bufferSize;
+        pBufferListDst->flatBuffers[0].dataLenInBytes = dstBufferSize;
         pBufferListDst->flatBuffers[0].bufferPhysAddr =
             virtAddrToDevAddr((SAMPLE_CODE_UINT *)(uintptr_t)pDstBuffer,
                               dcInstHandle,
@@ -290,11 +303,16 @@ static CpaStatus compPerformOp(CpaInstanceHandle dcInstHandle,
 
     if (CPA_STATUS_SUCCESS == status)
     {
-        /* Poll for responses.
+        /* Poll for responses if instance configured for polling.
          * Polling functions are implementation specific */
         do
         {
-            status = icp_sal_DcPollDpInstance(dcInstHandle, 1);
+#if defined(SC_BSD_UPSTREAM)
+            if (CPA_TRUE == info2.isPolled)
+#endif
+            {
+                status = icp_sal_DcPollDpInstance(dcInstHandle, 1);
+            }
         } while (
             ((CPA_STATUS_SUCCESS == status) || (CPA_STATUS_RETRY == status)) &&
             (pOpData->pCallbackTag == (void *)0));
@@ -399,11 +417,16 @@ static CpaStatus compPerformOp(CpaInstanceHandle dcInstHandle,
 
         if (CPA_STATUS_SUCCESS == status)
         {
-            /* Poll for responses.
+            /* Poll for responses if instance configured for polling.
              * Polling functions are implementation specific */
             do
             {
-                status = icp_sal_DcPollDpInstance(dcInstHandle, 1);
+#if defined(SC_BSD_UPSTREAM)
+                if (CPA_TRUE == info2.isPolled)
+#endif
+                {
+                    status = icp_sal_DcPollDpInstance(dcInstHandle, 1);
+                }
             } while (((CPA_STATUS_SUCCESS == status) ||
                       (CPA_STATUS_RETRY == status)) &&
                      (pOpData->pCallbackTag == (void *)0));
@@ -581,11 +604,13 @@ CpaStatus dcDpSample(void)
      * Set the address translation function for the instance
      */
     status = cpaDcSetAddressTranslation(dcInstHandle, sampleVirtToPhys);
-
-    /* Start DataCompression component */
-    PRINT_DBG("cpaDcStartInstance\n");
-    status =
-        cpaDcStartInstance(dcInstHandle, numInterBuffLists, bufferInterArray);
+    if (CPA_STATUS_SUCCESS == status)
+    {
+        /* Start DataCompression component */
+        PRINT_DBG("cpaDcStartInstance\n");
+        status = cpaDcStartInstance(
+            dcInstHandle, numInterBuffLists, bufferInterArray);
+    }
 
     if (CPA_STATUS_SUCCESS == status)
     {
