@@ -71,6 +71,8 @@
 #include "cpa_cy_im.h"
 #include "cpa_cy_sym.h"
 #include "cpa_sample_utils.h"
+#include <sys/stat.h>
+#include <unistd.h>
 
 extern int gDebugParam;
 
@@ -83,6 +85,70 @@ extern int gDebugParam;
 
 extern char *gFileName;
 
+typedef struct file_data_s
+{
+    Cpa8U **pSrcData;
+    Cpa32U *bufferSize;
+} file_data_t;
+
+/*
+ * This function copies a file to memory
+ */
+CpaStatus sample_getFile(const char *filename, file_data_t *file_data)
+{
+    FILE *srcFile = NULL;
+    Cpa8U *pBuff = NULL;
+    struct stat st = { 0 };
+    long file_size = 0;
+
+    /* Get filesize */
+    if (0 != stat(filename, &st))
+    {
+        PRINT_ERR("Could not get the file %s size\n", filename);
+        return CPA_STATUS_FAIL;
+    }
+    file_size = st.st_size;
+
+    /* Allocate memory for the file */
+    pBuff = (Cpa8U *)qaeMemAlloc(file_size);
+    if (NULL == pBuff)
+    {
+        PRINT_ERR("Could not allocate memory for the file copy\n");
+        return CPA_STATUS_FAIL;
+    }
+
+    memset(pBuff, 0, file_size);
+    /* Open the file */
+    srcFile = fopen((const char *)filename, "r");
+    if (NULL == (srcFile))
+    {
+        PRINT_ERR("Could not open source file %s\n", filename);
+        qaeMemFree((void **)&pBuff);
+        return CPA_STATUS_FAIL;
+    }
+
+    /* Read the file */
+    *(file_data->bufferSize) = fread(pBuff, 1, file_size, srcFile);
+    if (*(file_data->bufferSize) != file_size)
+    {
+        PRINT_ERR("Filesize doesn't match\n");
+        qaeMemFree((void **)&pBuff);
+        fclose(srcFile);
+        return CPA_STATUS_FAIL;
+    }
+
+    fclose(srcFile);
+    *(file_data->pSrcData) = pBuff;
+    return CPA_STATUS_SUCCESS;
+}
+
+/* Free the memory after getting the file and copying the data */
+CpaStatus sample_freeFile(file_data_t *file_data)
+{
+    qaeMemFree((void **)(file_data->pSrcData));
+    return CPA_STATUS_SUCCESS;
+}
+
 /* Forward declaration */
 CpaStatus hashFileSample(void);
 
@@ -139,11 +205,18 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
     Cpa8U *pDigestBuffer = NULL;
     FILE *srcFile = NULL;
     int i = 0;
+    CpaCySymCapabilitiesInfo symCapInfo = { 0 };
+    file_data_t inputData = { 0 };
+    CpaFlatBuffer inputBuffer = { 0 };
 
     /* The following variables are allocated on the stack because we block
      * until the callback comes back. If a non-blocking approach was to be
      * used then these variables should be dynamically allocated */
-    struct COMPLETION_STRUCT complete = { 0 };
+    struct COMPLETION_STRUCT complete;
+    /*
+     * Initialize the completion variable which is used by the callback
+     * function */
+    COMPLETION_INIT((&complete));
 
     /* Open file */
     srcFile = fopen(gFileName, "r");
@@ -157,6 +230,33 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
         PRINT_DBG("Processing file %s\n", gFileName);
     }
 
+    status = cpaCySymQueryCapabilities(cyInstHandle, &symCapInfo);
+    if (CPA_STATUS_SUCCESS != status)
+    {
+        PRINT_ERR("Failed to query capabilities, status = %d\n", status);
+        fclose(srcFile);
+        return status;
+    }
+
+    /* Check if partial packet support is available */
+    if (!symCapInfo.partialPacketSupported)
+    {
+        PRINT_DBG(
+            "Partial packets are not supported, using full packets instead.\n");
+
+        inputData.bufferSize = &inputBuffer.dataLenInBytes;
+        inputData.pSrcData = &inputBuffer.pData;
+        status = sample_getFile(gFileName, &inputData);
+
+        if (status != CPA_STATUS_SUCCESS)
+        {
+            PRINT_ERR("sample_getFile failed\n");
+            fclose(srcFile);
+            return status;
+        }
+        bufferSize = inputBuffer.dataLenInBytes;
+    }
+
     /* get meta information size */
     PRINT_DBG("cpaCyBufferListGetMetaSize\n");
     status =
@@ -200,34 +300,73 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
 
     if (CPA_STATUS_SUCCESS == status)
     {
-        /** initialization for callback; the "complete" variable is used by the
-         * callback function to indicate it has been called*/
-        COMPLETION_INIT((&complete));
-
-        //<snippet name="hashFile">
-        while (!feof(srcFile))
+        /* Check if partial packet processing is supported */
+        if (symCapInfo.partialPacketSupported)
         {
-            /* read from file into src buffer */
-            pBufferList->pBuffers->dataLenInBytes =
-                fread(pSrcBuffer, 1, SAMPLE_BUFF_SIZE, srcFile);
+            //<snippet name="hashFile">
+            while (!feof(srcFile))
+            {
+                /* read from file into src buffer */
+                pBufferList->pBuffers->dataLenInBytes =
+                    fread(pSrcBuffer, 1, SAMPLE_BUFF_SIZE, srcFile);
+                /* If we have reached the end of file set the last partial flag
+                 */
+                if (feof(srcFile))
+                {
+                    pOpData->packetType = CPA_CY_SYM_PACKET_TYPE_LAST_PARTIAL;
+                }
+                else
+                {
+                    pOpData->packetType = CPA_CY_SYM_PACKET_TYPE_PARTIAL;
+                }
+                pOpData->sessionCtx = sessionCtx;
+                pOpData->hashStartSrcOffsetInBytes = 0;
+                pOpData->messageLenToHashInBytes =
+                    pBufferList->pBuffers->dataLenInBytes;
+                pOpData->pDigestResult = pDigestBuffer;
+                PRINT_DBG("cpaCySymPerformOp\n");
+                /** Perform symmetric operation */
+                status = cpaCySymPerformOp(
+                    cyInstHandle,
+                    (void *)&complete, /* data sent as is to the callback
+                                          function*/
+                    pOpData,           /* operational data struct */
+                    pBufferList,       /* source buffer list */
+                    pBufferList, /* same src & dst for an in-place operation*/
+                    NULL);
 
-            /* If we have reached the end of file set the last partial flag */
-            if (feof(srcFile))
-            {
-                pOpData->packetType = CPA_CY_SYM_PACKET_TYPE_LAST_PARTIAL;
-            }
-            else
-            {
-                pOpData->packetType = CPA_CY_SYM_PACKET_TYPE_PARTIAL;
+                if (CPA_STATUS_SUCCESS != status)
+                {
+                    PRINT_ERR("cpaCySymPerformOp failed. (status = %d)\n",
+                              status);
+                    break;
+                }
+
+                if (CPA_STATUS_SUCCESS == status)
+                {
+                    /** wait until the completion of the operation*/
+                    if (!COMPLETION_WAIT((&complete), TIMEOUT_MS))
+                    {
+                        PRINT_ERR(
+                            "timeout or interruption in cpaCySymPerformOp\n");
+                        status = CPA_STATUS_FAIL;
+                        break;
+                    }
+                }
             }
+        }
+        else
+        {
+            /* Process as a single full packet if partial packets are not
+             * supported */
+            memcpy(pSrcBuffer, inputBuffer.pData, inputBuffer.dataLenInBytes);
+            pOpData->packetType = CPA_CY_SYM_PACKET_TYPE_FULL;
             pOpData->sessionCtx = sessionCtx;
             pOpData->hashStartSrcOffsetInBytes = 0;
-            pOpData->messageLenToHashInBytes =
-                pBufferList->pBuffers->dataLenInBytes;
+            pOpData->messageLenToHashInBytes = inputBuffer.dataLenInBytes;
             pOpData->pDigestResult = pDigestBuffer;
 
             PRINT_DBG("cpaCySymPerformOp\n");
-            /** Perform symmetric operation */
             status = cpaCySymPerformOp(
                 cyInstHandle,
                 (void *)&complete, /* data sent as is to the callback function*/
@@ -239,7 +378,6 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
             if (CPA_STATUS_SUCCESS != status)
             {
                 PRINT_ERR("cpaCySymPerformOp failed. (status = %d)\n", status);
-                break;
             }
 
             if (CPA_STATUS_SUCCESS == status)
@@ -249,12 +387,9 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
                 {
                     PRINT_ERR("timeout or interruption in cpaCySymPerformOp\n");
                     status = CPA_STATUS_FAIL;
-                    break;
                 }
             }
         }
-
-        //</snippet>
     }
 
     if (CPA_STATUS_SUCCESS == status)
@@ -282,6 +417,10 @@ static CpaStatus hashPerformOp(CpaInstanceHandle cyInstHandle,
     PHYS_CONTIG_FREE(pBufferMeta);
     PHYS_CONTIG_FREE(pDigestBuffer);
     OS_FREE(pOpData);
+    if (NULL != inputData.pSrcData)
+    {
+        sample_freeFile(&inputData);
+    }
 
     COMPLETION_DESTROY(&complete);
 
