@@ -164,6 +164,7 @@ static Cpa8U sampleIvExpected[] =
     {0xec, 0x63, 0xaa, 0x6d, 0x39, 0xc2, 0xb9, 0x94, 0x80, 0x3d, 0x24, 0xd9};
 
 extern int gDebugParam;
+CpaStatus hkdfSample(void);
 
 static void hkdfSampleCallback(void *pCallbackTag,
                                CpaStatus status,
@@ -230,6 +231,9 @@ static CpaStatus hkdfSampleExtractExpandLabelPerform(
      * used then these variables should be dynamically allocated */
     struct COMPLETION_STRUCT complete;
     CpaFlatBuffer hkdfOut;
+    /* Initialize the completion variable which is used by the callback
+     * function */
+    COMPLETION_INIT(&complete);
 
     status = PHYS_CONTIG_ALLOC(&pHkdfData, hkdfDataSize);
 
@@ -269,18 +273,10 @@ static CpaStatus hkdfSampleExtractExpandLabelPerform(
         pOpData->label[0].sublabelFlag = 0x00;
     }
 
-    /*
-     * Now, we initialize the completion variable which is used by the callback
-     * function
-     * to indicate that the operation is complete.  We then perform the
-     * operation.
-     */
     if (CPA_STATUS_SUCCESS == status)
     {
         PRINT_DBG("cpaCyKeyGenTls3\n");
 
-        COMPLETION_INIT(&complete);
-
         status = cpaCyKeyGenTls3(cyInstHandle,
                                  hkdfSampleCallback,
                                  (void *)&complete,
@@ -358,6 +354,9 @@ static CpaStatus hkdfSampleExtractExpandLabelSublabelsPerform(
      * used then these variables should be dynamically allocated */
     struct COMPLETION_STRUCT complete;
     CpaFlatBuffer hkdfOut;
+    /* Initialize the completion variable which is used by the callback
+     * function */
+    COMPLETION_INIT(&complete);
 
     status = PHYS_CONTIG_ALLOC(&pHkdfData, hkdfDataSize);
 
@@ -398,18 +397,10 @@ static CpaStatus hkdfSampleExtractExpandLabelSublabelsPerform(
         pOpData->label[0].sublabelFlag |= CPA_CY_HKDF_SUBLABEL_IV;
     }
 
-    /*
-     * Now, we initialize the completion variable which is used by the callback
-     * function
-     * to indicate that the operation is complete.  We then perform the
-     * operation.
-     */
     if (CPA_STATUS_SUCCESS == status)
     {
         PRINT_DBG("cpaCyKeyGenTls3\n");
 
-        COMPLETION_INIT(&complete);
-
         status = cpaCyKeyGenTls3(cyInstHandle,
                                  hkdfSampleCallback,
                                  (void *)&complete,
@@ -501,6 +492,10 @@ static CpaStatus hkdfSampleExtractExpandPerform(CpaInstanceHandle cyInstHandle)
      * used then these variables should be dynamically allocated */
     struct COMPLETION_STRUCT complete;
     CpaFlatBuffer hkdfOut;
+    /*
+     * Initialize the completion variable which is used by the callback
+     * function */
+    COMPLETION_INIT(&complete);
 
     status = PHYS_CONTIG_ALLOC(&pHkdfData, hkdfDataSize);
 
@@ -536,18 +531,10 @@ static CpaStatus hkdfSampleExtractExpandPerform(CpaInstanceHandle cyInstHandle)
         memcpy(pOpData->info, sampleInf, pOpData->infoLen);
     }
 
-    /*
-     * Now, we initialize the completion variable which is used by the callback
-     * function
-     * to indicate that the operation is complete.  We then perform the
-     * operation.
-     */
     if (CPA_STATUS_SUCCESS == status)
     {
         PRINT_DBG("cpaCyKeyGenTls3\n");
 
-        COMPLETION_INIT(&complete);
-
         status = cpaCyKeyGenTls3(cyInstHandle,
                                  hkdfSampleCallback,
                                  (void *)&complete,
@@ -608,17 +595,31 @@ CpaStatus hkdfSample(void)
     CpaStatus status = CPA_STATUS_FAIL;
     CpaInstanceHandle cyInstHandle = NULL;
     CpaInstanceInfo2 info = {0};
+    CpaCyCapabilitiesInfo cyCap = { 0 };
 
     /*
      * In this simplified version of instance discovery, we discover
      * exactly one instance of a crypto service.
      */
-    sampleCyGetInstance(&cyInstHandle);
+    sampleSymGetInstance(&cyInstHandle);
     if (cyInstHandle == NULL)
     {
         return CPA_STATUS_FAIL;
     }
 
+    status = cpaCyQueryCapabilities(cyInstHandle, &cyCap);
+    if (CPA_STATUS_SUCCESS != status)
+    {
+        PRINT_ERR("Failed to query capabilities, status = %d\n", status);
+        return status;
+    }
+
+    if (CPA_FALSE == cyCap.hkdfSupported)
+    {
+        PRINT("HKDF is not supported on this instance\n");
+        return CPA_STATUS_UNSUPPORTED;
+    }
+
     status = cpaCyInstanceGetInfo2(cyInstHandle, &info);
     if (CPA_STATUS_SUCCESS != status)
     {
