@@ -115,10 +115,34 @@
  * is performance stats, where each thread as a unique location to store stats
  *
  ******************************************************************************/
-
+#ifdef USER_SPACE
 /*store the threadId, this only used for thread setup and after threads are
  * complete, so it not required to be atomic*/
+sample_code_thread_t *threads_g;
+
+/*this array stores the setup and performance data of all threads created.
+ * there is duplication between this and testSetupData_g,
+ * however this makes it easier for collation of stats when there are
+ * multiple creations of one type of thread.
+ * There is no sharing data between threads*/
+single_thread_test_data_t *singleThreadData_g;
+
+/*this array stores the setup and performance data of ONE_TYPE_OF_THREAD. This
+ * is updated on thread setup and read and clear once all threads are complete*/
+thread_creation_data_t *testSetupData_g;
+
+/*declare space to store setup structures in. This stores all the setup of each
+ * thread, there is no sharing between threads, so each section of the array
+ * is autonomous to 1 thread*/
+Cpa8U (*thread_setup_g)[MAX_SETUP_STRUCT_SIZE_IN_BYTES];
+Cpa8U (*thread_name_g)[THREAD_NAME_LEN];
+#else
 sample_code_thread_t threads_g[MAX_THREADS];
+single_thread_test_data_t singleThreadData_g[MAX_THREADS] = {{0}};
+thread_creation_data_t testSetupData_g[MAX_THREAD_VARIATION] = {{0}};
+Cpa8U thread_setup_g[MAX_THREAD_VARIATION][MAX_SETUP_STRUCT_SIZE_IN_BYTES];
+Cpa8U thread_name_g[MAX_THREAD_VARIATION][THREAD_NAME_LEN];
+#endif
 
 /*declare array of perf_stats pointers. Each thread is provided is own
  * perf_stats */
@@ -130,26 +154,10 @@ CpaBoolean perfStatsInit_g = CPA_FALSE;
 int useStaticPrime = 1;
 int useUnalignedBuffer = 0;
 
-
 volatile CpaBoolean isChangingThreadQaInstanceRequired_g = CPA_FALSE;
 EXPORT_SYMBOL(isChangingThreadQaInstanceRequired_g);
 
-/*this array stores the setup and performance data of all threads created.
- * there is duplication between this and testSetupData_g,
- * however this makes it easier for collation of stats when there are
- * multiple creations of one type of thread.
- * There is no sharing data between threads*/
-single_thread_test_data_t singleThreadData_g[MAX_THREADS] = {{0}};
 
-/*this array stores the setup and performance data of ONE_TYPE_OF_THREAD. This
- * is updated on thread setup and read and clear once all threads are complete*/
-thread_creation_data_t testSetupData_g[MAX_THREAD_VARIATION] = {{0}};
-
-/*declare space to store setup structures in. This stores all the setup of each
- * thread, there is no sharing between threads, so each section of the array
- * is autonomous to 1 thread*/
-Cpa8U thread_setup_g[MAX_THREAD_VARIATION][MAX_SETUP_STRUCT_SIZE_IN_BYTES];
-Cpa8U thread_name_g[MAX_THREAD_VARIATION][THREAD_NAME_LEN];
 
 /*global variables -note syntax is to use _g for all global variables*/
 
@@ -237,7 +245,6 @@ volatile CpaBoolean enableReadInstance_g = CPA_FALSE;
 /* DC chaining specific variable to enable S/W write chaining operation */
 volatile CpaBoolean swWrite_g = CPA_FALSE;
 
-
 volatile CpaBoolean isNsRequest_g = CPA_FALSE;
 int verboseOutput = 1;
 
@@ -497,18 +504,30 @@ CpaStatus printFineTune(void)
 CpaStatus enableCycleCount(void)
 {
     iaCycleCount_g = CPA_CC_REQ_POLL_STAMP;
+#ifdef SC_BSD_UPSTREAM
+    singleInstRequired_g = CPA_TRUE;
+#endif
     return CPA_STATUS_SUCCESS;
 }
 
 CpaStatus disableCycleCount(void)
 {
     iaCycleCount_g = CPA_CC_DISABLE;
+#ifdef SC_BSD_UPSTREAM
+    singleInstRequired_g = CPA_FALSE;
+#endif
     return CPA_STATUS_SUCCESS;
 }
 
 CpaStatus setCycleCountMode(int mode)
 {
     iaCycleCount_g = mode;
+#ifdef SC_BSD_UPSTREAM
+    if (mode != CPA_CC_DISABLE)
+        singleInstRequired_g = CPA_TRUE;
+    else
+        singleInstRequired_g = CPA_FALSE;
+#endif
     return CPA_STATUS_SUCCESS;
 }
 
@@ -539,8 +558,6 @@ volatile CpaBoolean xltOverflow_g = CPA_FALSE;
 volatile CpaBoolean exitLoopFlag_g = CPA_FALSE;
 volatile CpaBoolean stopTestsIsEnabled_g = CPA_FALSE;
 
-
-
 /* This is function is used to save and restore members
  * of perf stats that should persist after clearing all
  * others.
@@ -831,11 +848,21 @@ CpaStatus waitForThreadCompletion(void)
             }
             if (CPA_TRUE == singleThreadData_g[i].isUsedByMega)
             {
+                if (CPA_STATUS_UNSUPPORTED ==
+                    singleThreadData_g[i].performanceStats->threadReturnStatus)
+                {
+                    status = CPA_STATUS_UNSUPPORTED;
+                }
                 if (CPA_STATUS_FAIL == status)
                 {
                     PRINT_ERR("Mega Thread using row %d failed\n",
                               singleThreadData_g[i].megaRowId);
                 }
+                else if (CPA_STATUS_UNSUPPORTED == status)
+                {
+                    PRINT("Mega Thread using row %d unsupported\n",
+                          singleThreadData_g[i].megaRowId);
+                }
                 else
                 {
                     PRINT("Mega Thread using row %d passed\n",
@@ -849,7 +876,11 @@ CpaStatus waitForThreadCompletion(void)
 #endif
         for (i = 0; i < testTypeCount_g; i++)
         {
-            statsPrintFunc = *(testSetupData_g[i].statsPrintFunc);
+	    if ((CPA_STATUS_UNSUPPORTED == status) ||(CPA_STATUS_UNSUPPORTED == singleThreadData_g[i].performanceStats->threadReturnStatus))
+            {
+		continue;
+            }
+	    statsPrintFunc = *(testSetupData_g[i].statsPrintFunc);
             if (statsPrintFunc != NULL)
             {
                 statusPrintFunc = statsPrintFunc(&testSetupData_g[i]);
@@ -1250,10 +1281,15 @@ void getLongestCycleCount(perf_data_t *dest, perf_data_t *src[], Cpa32U count)
 {
     Cpa32U i = 0;
 
-    if (NULL != dest && NULL != src && NULL != src[0])
+    for (i = 0; i < count; i++)
     {
-        dest->startCyclesTimestamp = src[0]->startCyclesTimestamp;
-        dest->endCyclesTimestamp = src[0]->endCyclesTimestamp;
+        if (src[i]->threadReturnStatus == CPA_STATUS_SUCCESS)
+            break;
+    }
+    if (NULL != dest && NULL != src && NULL != src[i])
+    {
+        dest->startCyclesTimestamp = src[i]->startCyclesTimestamp;
+        dest->endCyclesTimestamp = src[i]->endCyclesTimestamp;
     }
     else
     {
@@ -1263,15 +1299,18 @@ void getLongestCycleCount(perf_data_t *dest, perf_data_t *src[], Cpa32U count)
     }
     for (i = 1; i < count; i++)
     {
-        /*get the lowest start time*/
-        if ((src[i]->startCyclesTimestamp < dest->startCyclesTimestamp))
+        if (src[i]->threadReturnStatus == CPA_STATUS_SUCCESS)
         {
-            dest->startCyclesTimestamp = src[i]->startCyclesTimestamp;
-        }
-        /*get the high finish time*/
-        if ((src[i]->endCyclesTimestamp > dest->endCyclesTimestamp))
-        {
-            dest->endCyclesTimestamp = src[i]->endCyclesTimestamp;
+            /*get the lowest start time*/
+            if ((src[i]->startCyclesTimestamp < dest->startCyclesTimestamp))
+            {
+                dest->startCyclesTimestamp = src[i]->startCyclesTimestamp;
+            }
+            /*get the high finish time*/
+            if ((src[i]->endCyclesTimestamp > dest->endCyclesTimestamp))
+            {
+                dest->endCyclesTimestamp = src[i]->endCyclesTimestamp;
+            }
         }
     }
 }
@@ -1481,12 +1520,11 @@ CpaStatus getCryptoInstanceMapping(void)
                 if (verboseOutput)
                 {
                     PRINT("Inst %u, Affin: %u, Dev: %u, Accel %u, "
-                          "EE %u, BDF %02X:%02X:%02X\n",
+                          "BDF %02X:%02X:%02X\n",
                           i,
                           coreAffinity,
                           info.physInstId.packageId,
                           info.physInstId.acceleratorId,
-                          info.physInstId.executionEngineId,
                           (Cpa8U)((info.physInstId.busAddress) >> 8),
                           (Cpa8U)((info.physInstId.busAddress) & 0xFF) >> 3,
                           (Cpa8U)((info.physInstId.busAddress) & 7));
@@ -1585,19 +1623,6 @@ CpaStatus getSymInstanceMapping(Cpa16U *numSymInstances)
                 {
                     packageIdCount_g = info.physInstId.packageId;
                 }
-                if (verboseOutput)
-                {
-                    PRINT("Inst %u, Affin: %u, Dev: %u, Accel %u, "
-                          "EE %u, BDF %02X:%02X:%02X\n",
-                          i,
-                          coreAffinity,
-                          info.physInstId.packageId,
-                          info.physInstId.acceleratorId,
-                          info.physInstId.executionEngineId,
-                          (Cpa8U)((info.physInstId.busAddress) >> 8),
-                          (Cpa8U)((info.physInstId.busAddress) & 0xFF) >> 3,
-                          (Cpa8U)((info.physInstId.busAddress) & 7));
-                }
                 if (info.isPolled)
                     symCyInstMap_g[i] = coreAffinity;
                 else
@@ -1691,19 +1716,6 @@ CpaStatus getAsymInstanceMapping(Cpa16U *numAsymInstances)
                 {
                     packageIdCount_g = info.physInstId.packageId;
                 }
-                if (verboseOutput)
-                {
-                    PRINT("Inst %u, Affin: %u, Dev: %u, Accel %u, "
-                          "EE %u, BDF %02X:%02X:%02X\n",
-                          i,
-                          coreAffinity,
-                          info.physInstId.packageId,
-                          info.physInstId.acceleratorId,
-                          info.physInstId.executionEngineId,
-                          (Cpa8U)((info.physInstId.busAddress) >> 8),
-                          (Cpa8U)((info.physInstId.busAddress) & 0xFF) >> 3,
-                          (Cpa8U)((info.physInstId.busAddress) & 7));
-                }
                 if (info.isPolled)
                     asymCyInstMap_g[i] = coreAffinity;
                 else
@@ -1800,12 +1812,11 @@ CpaStatus getCompressionInstanceMapping(void)
                 if (verboseOutput)
                 {
                     PRINT("Inst %u, Affin: %u, Dev: %u, Accel %u, "
-                          "EE %u, BDF %02X:%02X:%02X\n",
+                          "BDF %02X:%02X:%02X\n",
                           i,
                           coreAffinity,
                           info.physInstId.packageId,
                           info.physInstId.acceleratorId,
-                          info.physInstId.executionEngineId,
                           (Cpa8U)((info.physInstId.busAddress) >> 8),
                           (Cpa8U)((info.physInstId.busAddress) & 0xFF) >> 3,
                           (Cpa8U)((info.physInstId.busAddress) & 7));
@@ -1863,7 +1874,8 @@ CpaStatus createStartandWaitForCompletion(Cpa32U instType)
     Cpa16U nSymInstances = 0;
     Cpa16U nAsymInstances = 0;
 
-    if (instType != COMPRESSION)
+    if ((instType != COMPRESSION)
+    )
     {
         cpaGetNumInstances(CPA_ACC_SVC_TYPE_CRYPTO_SYM, &nSymInstances);
         cpaGetNumInstances(CPA_ACC_SVC_TYPE_CRYPTO_ASYM, &nAsymInstances);
@@ -1997,6 +2009,69 @@ CpaStatus createStartandWaitForCompletion(Cpa32U instType)
     freeInstanceMapping();
     return status;
 }
+CpaStatus allocThreadMem()
+{
+#ifdef USER_SPACE
+   testSetupData_g = qaeMemAlloc(sizeof(thread_creation_data_t) * MAX_THREAD_VARIATION);
+   if(testSetupData_g == NULL)
+   {
+      PRINT_ERR("Failed to allocate memory for testSetupData\n");
+      return CPA_STATUS_FAIL;
+   }
+   singleThreadData_g = qaeMemAlloc(sizeof(single_thread_test_data_t) * MAX_THREADS);
+   if(singleThreadData_g ==NULL)
+   {
+      PRINT_ERR("Failed to allocate memory for singleThreadData\n");
+      return CPA_STATUS_FAIL;
+    }
+   threads_g = qaeMemAlloc(sizeof(sample_code_thread_t) * MAX_THREADS);
+   if(threads_g ==NULL)
+   {
+      PRINT_ERR("Failed to allocate memory for thread\n");
+      return CPA_STATUS_FAIL;
+   }
+   thread_setup_g = qaeMemAlloc(sizeof(*thread_setup_g) * MAX_THREAD_VARIATION);
+   if (*thread_setup_g == NULL)
+   {
+       PRINT_ERR("Failed to allocate memory for thread_setup_g\n");
+       return CPA_STATUS_FAIL;
+   }
+   thread_name_g = qaeMemAlloc(sizeof(*thread_name_g) * MAX_THREAD_VARIATION);
+   if (*thread_name_g == NULL)
+   {
+      PRINT_ERR("Failed to allocate memory for thread_name_g\n");
+      return CPA_STATUS_FAIL;
+   }
+#endif
+   return CPA_STATUS_SUCCESS;
+}
+EXPORT_SYMBOL(allocThreadMem);
+void freeThreadMem()
+{
+#ifdef USER_SPACE
+   if(testSetupData_g != NULL)
+   {
+      qaeMemFree((void **)&testSetupData_g);
+   }
+   if(singleThreadData_g != NULL)
+   {
+      qaeMemFree((void **)&singleThreadData_g);
+   }
+   if(threads_g!= NULL)
+   {
+      qaeMemFree((void **)&threads_g);
+   }
+   if((*thread_setup_g) != NULL)
+   {
+      qaeMemFree((void **)&(thread_setup_g));
+   }
+   if((*thread_name_g) != NULL)
+   {
+       qaeMemFree((void **)&(thread_name_g));
+   }
+#endif
+}
+EXPORT_SYMBOL(freeThreadMem);
 
 int latency_debug = 0; /* set to 1 for debug PRINT() */
 EXPORT_SYMBOL(latency_debug);
